Code of Conduct
==============================================================================
This project has adopted the `Amazon Open Source Code of Conduct <https://aws.github.io/code-of-conduct>`_.
For more information see the `Code of Conduct FAQ <https://aws.github.io/code-of-conduct-faq>`_ or contact opensource-codeofconduct@amazon.com with any additional questions or comments.